@@ -121,6 +121,9 @@ impl std::convert::TryInto<Issues> for Clippy {
         let mut cmd = Command::new("cargo");
         cmd.arg("clippy")
             .arg("--message-format=json")
+            .arg("--")
+            .arg("--warn")
+            .arg("clippy::pedantic")
             .stdout(Stdio::piped())
             .stderr(Stdio::null());
         debug!("execute `{:?}`", cmd);
